@@ -1,21 +1,27 @@
 name = "pyxem"
-version = "0.11.0"
-author = "Duncan Johnstone, Phillip Crout"
-copyright = "copyright 2016-2020, the pyxem developers"
+version = "0.12.0"
+author = "Duncan Johnstone, Phillip Crout, Magnus Nord"
+copyright = "Copyright 2016-2020, The pyXem Developers"
 credits = [
     "Duncan Johnstone",
     "Phillip Crout",
+    "Magnus Nord",
     "Joonatan Laulainen",
     "Simon Høgås",
+    "Eirik Opheim",
     "Ben Martineau",
     "Tina Bergh",
     "Stef Smeets",
     "Carter Francis",
-    "Eirik Opheim",
     "Eric Prestat",
+    "Andrew Ross",
     "Sean Collins",
+    "Daen Jannis",
+    "Ida Hjorth",
     "Tom Furnival",
+    "Endre Jacobsen",
     "Mohsen Danaie",
+    "Andrew Herzing",
     "Håkon Wiik Ånes",
     "Tiarnan Doherty",
     "Affan Iqbal",
@@ -24,9 +30,8 @@ credits = [
     "Rob Tovey",
     "Matt von Lany",
     "Tim Poon",
-    "Endre Jacobsen",
 ]
 license = "GPLv3"
-maintainer = "Duncan Johnstone, Phillip Crout"
+maintainer = "Duncan Johnstone, Phillip Crout, Magnus Nord"
 email = "pyxem.team@gmail.com"
 status = "development"
